/*
 * Copyright (C) 2014 Rolf Eike Beer <eike@sf-mail.de>
 */

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#include "osmnode.h"

#include <marble/GeoDataPlacemark.h>
#include <QString>

static const QString key_ref = QLatin1String("ref");
static const QString key_wtank_volume = QLatin1String("water_tank:volume");
static const QString key_diam = QLatin1String("fire_hydrant:diameter");
static const QString key_type = QLatin1String("fire_hydrant:type");

Marble::GeoDataPlacemark *
OSMNode::getPlacemark(void)
{
	if (m_placemark == nullptr)
		m_placemark = new Marble::GeoDataPlacemark(placemarkName());

	return m_placemark;
}

QString
OSMNode::placemarkName(void) const
{
	return QLatin1String("?");
}

QString
FireHydrant::placemarkName(void) const
{
	QString nm;

	const uint diameter = m_attributes.value(key_diam, "0").toUInt();
	const QString type = m_attributes.value(key_type);

	if (type.isEmpty())
		nm = QLatin1Char('?');
	else if (type == QLatin1String("underground"))
		nm = QLatin1String("UF");
	else
		nm = type;

	if (diameter > 0)
		nm = nm + QLatin1Char(' ') + QString::number(diameter);

	return nm;
}

QString
WaterTank::placemarkName(void) const
{
	QString nm = QLatin1String("Z");

	const QString volume = m_attributes.value(key_wtank_volume);
	if (!volume.isEmpty()) {
		uint vol = volume.toUInt();
		if (vol != 0)
			nm += QString::number(vol / 1000);
	}

	return nm;
}

QString
EmergencyAccessPoint::placemarkName(void) const
{
	const QString ref = m_attributes.value(key_ref);
	static const QString label_EAP = QLatin1String("EAP");

	if (ref.isEmpty())
		return label_EAP;
	else
		return label_EAP + QLatin1Char(' ') + ref;
}
