/*
 * Copyright (C) 2014 Rolf Eike Beer <eike@sf-mail.de>
 */

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#pragma once

#include <qglobal.h>
#include <QHash>

namespace Marble {
	class GeoDataPlacemark;
};

class OSMNode {
	OSMNode() = delete;
public:
	OSMNode(double lat, double lon, QHash<QString, QString> attributes = QHash<QString, QString>())
		: m_lat(lat)
		, m_lon(lon)
		, m_attributes(attributes)
		, m_placemark(nullptr)
	{
	}

	const double m_lat;
	const double m_lon;
	const QHash<QString, QString> m_attributes;

	Marble::GeoDataPlacemark *getPlacemark(void);

protected:
	virtual QString placemarkName(void) const;
private:
	Marble::GeoDataPlacemark *m_placemark;
};

class FireHydrant : public OSMNode {
	FireHydrant() = delete;
public:
	FireHydrant(double lat, double lon, QHash<QString, QString> attributes = QHash<QString, QString>())
		: OSMNode(lat, lon, attributes)
	{
	}

protected:
	virtual QString placemarkName(void) const;
};

class WaterTank : public OSMNode {
	WaterTank() = delete;
public:
	WaterTank(double lat, double lon, QHash<QString, QString> attributes = QHash<QString, QString>())
		: OSMNode(lat, lon, attributes)
	{
	}

protected:
	virtual QString placemarkName(void) const;
};

class EmergencyAccessPoint: public OSMNode {
	EmergencyAccessPoint() = delete;
public:
	EmergencyAccessPoint(double lat, double lon, QHash<QString, QString> attributes = QHash<QString, QString>())
		: OSMNode(lat, lon, attributes)
	{
	}

protected:
	virtual QString placemarkName(void) const;
};
